@@ -10,7 +10,7 @@
 #' \describe{
 #'   \item{Isolate}{*P. sojae* isolate identifier}
 #'   \item{Line}{Soybean cultivar}
-#'   \item{Rps}{*Rps* gene identifer}
+#'   \item{Rps}{*Rps* gene identifier}
 #'   \item{Total}{Total number of plants inoculated}
 #'   \item{HR (1)}{Number of plants that exhibit a hypersensitive response after
 #'    inoculation}
@@ -35,3 +35,29 @@
 #' P_sojae_survey
 #'
 "P_sojae_survey"
+
+#' *Phytophthora sojae* survey example metadata
+#'
+#' Metadata to accompany internal data from a *Phytophthora sojae* survey used
+#' for an example in the "Beta-diversity Analyses" vignette.
+#'
+#' @docType data
+#'
+#' @usage data(sample_meta)
+#'
+#' @format An object of class `data.frame` with 21 observations of 2 variables
+#' \describe{
+#'   \item{Sample}{*P. sojae* sample identifier}
+#'   \item{Locale}{US State where sample was collected, limited to Michigan}
+#'   }
+#'
+#' @keywords datasets
+#'
+#' @source Data from an ongoing 2017 *Phytophthora sojae* survey in Michigan,
+#' conducted by A. G. McCoy *et al.*.
+#'
+#' @examples
+#' data(sample_meta)
+#' sample_meta
+#'
+"sample_meta"
